LanguageBuf

Struct LanguageBuf 

pub struct LanguageBuf(/* private fields */);
Owned language.

Implementations

Source

impl LanguageBuf

pub fn new<T: Buffer>(input: T) -> Result<Self, InvalidLanguage<T>>

Creates a new owned language by parsing the input value.

pub fn from_bytes(input: Vec<u8>) -> Result<Self, InvalidLanguage<Vec<u8>>>

Creates a new owned language by parsing the input bytes.

pub fn from_string(input: String) -> Result<Self, InvalidLanguage<String>>

Creates a new owned language by parsing the input string.

pub unsafe fn new_unchecked(input: impl Into<Vec<u8>>) -> Self

Creates a new owned language from the input value without validation.

Safety

The input value must be a valid language.

pub const fn as_language(&self) -> &Language

Source

impl LanguageBuf

pub fn as_str(&self) -> &str

Returns the language as a string.

pub fn as_bytes(&self) -> &[u8]

Returns the language as a byte string.

pub fn into_string(self) -> String

pub fn into_bytes(self) -> Vec<u8>

Methods from Deref<Target = Language>

pub fn as_str(&self) -> &str

Returns the language as a string.

pub fn as_bytes(&self) -> &[u8]

Returns the language as a byte string.

pub fn primary(&self) -> &PrimaryLanguage

Return the primary language subtag.

The primary language subtag is the first subtag in a language tag.

pub fn extension(&self) -> Option<&LanguageExtension>

Return the extended language subtags.

Extended language subtags are used to identify certain specially selected languages that, for various historical and compatibility reasons, are closely identified with or tagged using an existing primary language subtag.

Extended language subtags are only present when the primary language subtag length is 2 or 3.

pub fn extension_subtags(&self) -> LanguageExtensionIter<'_>

Return an iterator to the extended language subtags.