pub struct NormalLangTag(/* private fields */);Expand description
Normal language tag.
Implementations
Sourceimpl NormalLangTag
impl NormalLangTag
pub const fn validate_str(input: &str) -> bool
pub const fn validate_bytes(input: &[u8]) -> bool
Sourceimpl NormalLangTag
impl NormalLangTag
Sourcepub fn new<T: ?Sized + AsRef<[u8]>>(
input: &T,
) -> Result<&Self, InvalidNormalLangTag<&T>>
pub fn new<T: ?Sized + AsRef<[u8]>>( input: &T, ) -> Result<&Self, InvalidNormalLangTag<&T>>
Creates a new normallangtag by parsing the input value.
Sourcepub const fn from_bytes(
input: &[u8],
) -> Result<&Self, InvalidNormalLangTag<&[u8]>>
pub const fn from_bytes( input: &[u8], ) -> Result<&Self, InvalidNormalLangTag<&[u8]>>
Creates a new normallangtag by parsing the input bytes.
Sourcepub const fn from_str(input: &str) -> Result<&Self, InvalidNormalLangTag<&str>>
pub const fn from_str(input: &str) -> Result<&Self, InvalidNormalLangTag<&str>>
Creates a new normallangtag by parsing the input string.
Sourcepub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self
pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self
Creates a new normallangtag from the input bytes without validation.
Safety
The input bytes must be a valid normallangtag.
Sourcepub const unsafe fn new_unchecked(input: &str) -> &Self
pub const unsafe fn new_unchecked(input: &str) -> &Self
Creates a new normallangtag from the input string without validation.
Safety
The input string must be a valid normallangtag.
Sourceimpl NormalLangTag
impl NormalLangTag
Sourceimpl NormalLangTag
impl NormalLangTag
Sourcepub fn extensions(&self) -> &Extensions
pub fn extensions(&self) -> &Extensions
Returns the extension subtags.
Sourcepub fn private_use(&self) -> Option<&PrivateUse>
pub fn private_use(&self) -> Option<&PrivateUse>
Returns the private use subtags.