VariantsBuf

Struct VariantsBuf 

pub struct VariantsBuf(/* private fields */);
Owned variants.

Implementations

Source

impl VariantsBuf

pub fn new<T: Buffer>(input: T) -> Result<Self, InvalidVariants<T>>

Creates a new owned variants by parsing the input value.

pub fn from_bytes(input: Vec<u8>) -> Result<Self, InvalidVariants<Vec<u8>>>

Creates a new owned variants by parsing the input bytes.

pub fn from_string(input: String) -> Result<Self, InvalidVariants<String>>

Creates a new owned variants by parsing the input string.

pub unsafe fn new_unchecked(input: impl Into<Vec<u8>>) -> Self

Creates a new owned variants from the input value without validation.

Safety

The input value must be a valid variants.

pub const fn as_variants(&self) -> &Variants

Source

impl VariantsBuf

pub fn as_str(&self) -> &str

Returns the variants as a string.

pub fn as_bytes(&self) -> &[u8]

Returns the variants as a byte string.

pub fn into_string(self) -> String

pub fn into_bytes(self) -> Vec<u8>

Methods from Deref<Target = Variants>

pub fn as_str(&self) -> &str

Returns the variants as a string.

pub fn as_bytes(&self) -> &[u8]

Returns the variants as a byte string.

pub const EMPTY: &Self

pub fn iter(&self) -> VariantsIter<'_>

pub fn first(&self) -> Option<&Variant>

pub fn last(&self) -> Option<&Variant>