NormalLangTag

Struct NormalLangTag 

pub struct NormalLangTag(/* private fields */);
Normal language tag.

Implementations

Source

impl NormalLangTag

pub const fn validate_str(input: &str) -> bool

pub const fn validate_bytes(input: &[u8]) -> bool

Source

impl NormalLangTag

pub fn new<T: ?Sized + AsRef<[u8]>>( input: &T, ) -> Result<&Self, InvalidNormalLangTag<&T>>

Creates a new normallangtag by parsing the input value.

pub const fn from_bytes( input: &[u8], ) -> Result<&Self, InvalidNormalLangTag<&[u8]>>

Creates a new normallangtag by parsing the input bytes.

pub const fn from_str(input: &str) -> Result<&Self, InvalidNormalLangTag<&str>>

Creates a new normallangtag by parsing the input string.

pub const unsafe fn new_unchecked_from_bytes(input: &[u8]) -> &Self

Creates a new normallangtag from the input bytes without validation.

Safety

The input bytes must be a valid normallangtag.

pub const unsafe fn new_unchecked(input: &str) -> &Self

Creates a new normallangtag from the input string without validation.

Safety

The input string must be a valid normallangtag.

Source

impl NormalLangTag

pub const fn as_str(&self) -> &str

Returns the normallangtag as a string.

pub const fn as_bytes(&self) -> &[u8]

Returns the normallangtag as a byte string.

Source

impl NormalLangTag

pub fn language(&self) -> &Language

Returns the language subtags.

pub fn script(&self) -> Option<&Script>

Returns the script subtag, if any.

pub fn region(&self) -> Option<&Region>

Returns the region subtag, if any.

pub fn variants(&self) -> &Variants

Returns the variant subtags.

pub fn extensions(&self) -> &Extensions

Returns the extension subtags.

pub fn private_use(&self) -> Option<&PrivateUse>

Returns the private use subtags.

pub fn private_use_subtags(&self) -> PrivateUseIter<'_>